# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsApiTestFailureCode(ModelSimple):
    """
    Error code that can be returned by a Synthetic test.

    :param value: Must be one of ["BODY_TOO_LARGE", "DENIED", "TOO_MANY_REDIRECTS", "AUTHENTICATION_ERROR", "DECRYPTION", "INVALID_CHAR_IN_HEADER", "HEADER_TOO_LARGE", "HEADERS_INCOMPATIBLE_CONTENT_LENGTH", "INVALID_REQUEST", "REQUIRES_UPDATE", "UNESCAPED_CHARACTERS_IN_REQUEST_PATH", "MALFORMED_RESPONSE", "INCORRECT_ASSERTION", "CONNREFUSED", "CONNRESET", "DNS", "HOSTUNREACH", "NETUNREACH", "TIMEOUT", "SSL", "OCSP", "INVALID_TEST", "TUNNEL", "WEBSOCKET", "UNKNOWN", "INTERNAL_ERROR"].
    :type value: str
    """

    allowed_values = {
        "BODY_TOO_LARGE",
        "DENIED",
        "TOO_MANY_REDIRECTS",
        "AUTHENTICATION_ERROR",
        "DECRYPTION",
        "INVALID_CHAR_IN_HEADER",
        "HEADER_TOO_LARGE",
        "HEADERS_INCOMPATIBLE_CONTENT_LENGTH",
        "INVALID_REQUEST",
        "REQUIRES_UPDATE",
        "UNESCAPED_CHARACTERS_IN_REQUEST_PATH",
        "MALFORMED_RESPONSE",
        "INCORRECT_ASSERTION",
        "CONNREFUSED",
        "CONNRESET",
        "DNS",
        "HOSTUNREACH",
        "NETUNREACH",
        "TIMEOUT",
        "SSL",
        "OCSP",
        "INVALID_TEST",
        "TUNNEL",
        "WEBSOCKET",
        "UNKNOWN",
        "INTERNAL_ERROR",
    }
    BODY_TOO_LARGE: ClassVar["SyntheticsApiTestFailureCode"]
    DENIED: ClassVar["SyntheticsApiTestFailureCode"]
    TOO_MANY_REDIRECTS: ClassVar["SyntheticsApiTestFailureCode"]
    AUTHENTICATION_ERROR: ClassVar["SyntheticsApiTestFailureCode"]
    DECRYPTION: ClassVar["SyntheticsApiTestFailureCode"]
    INVALID_CHAR_IN_HEADER: ClassVar["SyntheticsApiTestFailureCode"]
    HEADER_TOO_LARGE: ClassVar["SyntheticsApiTestFailureCode"]
    HEADERS_INCOMPATIBLE_CONTENT_LENGTH: ClassVar["SyntheticsApiTestFailureCode"]
    INVALID_REQUEST: ClassVar["SyntheticsApiTestFailureCode"]
    REQUIRES_UPDATE: ClassVar["SyntheticsApiTestFailureCode"]
    UNESCAPED_CHARACTERS_IN_REQUEST_PATH: ClassVar["SyntheticsApiTestFailureCode"]
    MALFORMED_RESPONSE: ClassVar["SyntheticsApiTestFailureCode"]
    INCORRECT_ASSERTION: ClassVar["SyntheticsApiTestFailureCode"]
    CONNREFUSED: ClassVar["SyntheticsApiTestFailureCode"]
    CONNRESET: ClassVar["SyntheticsApiTestFailureCode"]
    DNS: ClassVar["SyntheticsApiTestFailureCode"]
    HOSTUNREACH: ClassVar["SyntheticsApiTestFailureCode"]
    NETUNREACH: ClassVar["SyntheticsApiTestFailureCode"]
    TIMEOUT: ClassVar["SyntheticsApiTestFailureCode"]
    SSL: ClassVar["SyntheticsApiTestFailureCode"]
    OCSP: ClassVar["SyntheticsApiTestFailureCode"]
    INVALID_TEST: ClassVar["SyntheticsApiTestFailureCode"]
    TUNNEL: ClassVar["SyntheticsApiTestFailureCode"]
    WEBSOCKET: ClassVar["SyntheticsApiTestFailureCode"]
    UNKNOWN: ClassVar["SyntheticsApiTestFailureCode"]
    INTERNAL_ERROR: ClassVar["SyntheticsApiTestFailureCode"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsApiTestFailureCode.BODY_TOO_LARGE = SyntheticsApiTestFailureCode("BODY_TOO_LARGE")
SyntheticsApiTestFailureCode.DENIED = SyntheticsApiTestFailureCode("DENIED")
SyntheticsApiTestFailureCode.TOO_MANY_REDIRECTS = SyntheticsApiTestFailureCode("TOO_MANY_REDIRECTS")
SyntheticsApiTestFailureCode.AUTHENTICATION_ERROR = SyntheticsApiTestFailureCode("AUTHENTICATION_ERROR")
SyntheticsApiTestFailureCode.DECRYPTION = SyntheticsApiTestFailureCode("DECRYPTION")
SyntheticsApiTestFailureCode.INVALID_CHAR_IN_HEADER = SyntheticsApiTestFailureCode("INVALID_CHAR_IN_HEADER")
SyntheticsApiTestFailureCode.HEADER_TOO_LARGE = SyntheticsApiTestFailureCode("HEADER_TOO_LARGE")
SyntheticsApiTestFailureCode.HEADERS_INCOMPATIBLE_CONTENT_LENGTH = SyntheticsApiTestFailureCode(
    "HEADERS_INCOMPATIBLE_CONTENT_LENGTH"
)
SyntheticsApiTestFailureCode.INVALID_REQUEST = SyntheticsApiTestFailureCode("INVALID_REQUEST")
SyntheticsApiTestFailureCode.REQUIRES_UPDATE = SyntheticsApiTestFailureCode("REQUIRES_UPDATE")
SyntheticsApiTestFailureCode.UNESCAPED_CHARACTERS_IN_REQUEST_PATH = SyntheticsApiTestFailureCode(
    "UNESCAPED_CHARACTERS_IN_REQUEST_PATH"
)
SyntheticsApiTestFailureCode.MALFORMED_RESPONSE = SyntheticsApiTestFailureCode("MALFORMED_RESPONSE")
SyntheticsApiTestFailureCode.INCORRECT_ASSERTION = SyntheticsApiTestFailureCode("INCORRECT_ASSERTION")
SyntheticsApiTestFailureCode.CONNREFUSED = SyntheticsApiTestFailureCode("CONNREFUSED")
SyntheticsApiTestFailureCode.CONNRESET = SyntheticsApiTestFailureCode("CONNRESET")
SyntheticsApiTestFailureCode.DNS = SyntheticsApiTestFailureCode("DNS")
SyntheticsApiTestFailureCode.HOSTUNREACH = SyntheticsApiTestFailureCode("HOSTUNREACH")
SyntheticsApiTestFailureCode.NETUNREACH = SyntheticsApiTestFailureCode("NETUNREACH")
SyntheticsApiTestFailureCode.TIMEOUT = SyntheticsApiTestFailureCode("TIMEOUT")
SyntheticsApiTestFailureCode.SSL = SyntheticsApiTestFailureCode("SSL")
SyntheticsApiTestFailureCode.OCSP = SyntheticsApiTestFailureCode("OCSP")
SyntheticsApiTestFailureCode.INVALID_TEST = SyntheticsApiTestFailureCode("INVALID_TEST")
SyntheticsApiTestFailureCode.TUNNEL = SyntheticsApiTestFailureCode("TUNNEL")
SyntheticsApiTestFailureCode.WEBSOCKET = SyntheticsApiTestFailureCode("WEBSOCKET")
SyntheticsApiTestFailureCode.UNKNOWN = SyntheticsApiTestFailureCode("UNKNOWN")
SyntheticsApiTestFailureCode.INTERNAL_ERROR = SyntheticsApiTestFailureCode("INTERNAL_ERROR")



"""
Change the triage state of a security signal returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi
from datadog_api_client.v2.model.security_monitoring_signal_archive_reason import SecurityMonitoringSignalArchiveReason
from datadog_api_client.v2.model.security_monitoring_signal_state import SecurityMonitoringSignalState
from datadog_api_client.v2.model.security_monitoring_signal_state_update_attributes import (
    SecurityMonitoringSignalStateUpdateAttributes,
)
from datadog_api_client.v2.model.security_monitoring_signal_state_update_data import (
    SecurityMonitoringSignalStateUpdateData,
)
from datadog_api_client.v2.model.security_monitoring_signal_state_update_request import (
    SecurityMonitoringSignalStateUpdateRequest,
)

body = SecurityMonitoringSignalStateUpdateRequest(
    data=SecurityMonitoringSignalStateUpdateData(
        attributes=SecurityMonitoringSignalStateUpdateAttributes(
            archive_reason=SecurityMonitoringSignalArchiveReason.NONE,
            state=SecurityMonitoringSignalState.OPEN,
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    response = api_instance.edit_security_monitoring_signal_state(
        signal_id="AQAAAYG1bl5K4HuUewAAAABBWUcxYmw1S0FBQmt2RmhRN0V4ZUVnQUE", body=body
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Dict, List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_basic_auth import SyntheticsBasicAuth
    from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
    from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHeaders
    from datadog_api_client.v1.model.synthetics_ci_batch_metadata import SyntheticsCIBatchMetadata
    from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry
    from datadog_api_client.v1.model.synthetics_basic_auth_web import SyntheticsBasicAuthWeb
    from datadog_api_client.v1.model.synthetics_basic_auth_sigv4 import SyntheticsBasicAuthSigv4
    from datadog_api_client.v1.model.synthetics_basic_auth_ntlm import SyntheticsBasicAuthNTLM
    from datadog_api_client.v1.model.synthetics_basic_auth_digest import SyntheticsBasicAuthDigest
    from datadog_api_client.v1.model.synthetics_basic_auth_oauth_client import SyntheticsBasicAuthOauthClient
    from datadog_api_client.v1.model.synthetics_basic_auth_oauth_rop import SyntheticsBasicAuthOauthROP


class SyntheticsCITest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_basic_auth import SyntheticsBasicAuth
        from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
        from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHeaders
        from datadog_api_client.v1.model.synthetics_ci_batch_metadata import SyntheticsCIBatchMetadata
        from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry

        return {
            "allow_insecure_certificates": (bool,),
            "basic_auth": (SyntheticsBasicAuth,),
            "body": (str,),
            "body_type": (str,),
            "cookies": (str,),
            "device_ids": ([SyntheticsDeviceID],),
            "follow_redirects": (bool,),
            "headers": (SyntheticsTestHeaders,),
            "locations": ([str],),
            "metadata": (SyntheticsCIBatchMetadata,),
            "public_id": (str,),
            "retry": (SyntheticsTestOptionsRetry,),
            "start_url": (str,),
            "variables": ({str: (str,)},),
        }

    attribute_map = {
        "allow_insecure_certificates": "allowInsecureCertificates",
        "basic_auth": "basicAuth",
        "body": "body",
        "body_type": "bodyType",
        "cookies": "cookies",
        "device_ids": "deviceIds",
        "follow_redirects": "followRedirects",
        "headers": "headers",
        "locations": "locations",
        "metadata": "metadata",
        "public_id": "public_id",
        "retry": "retry",
        "start_url": "startUrl",
        "variables": "variables",
    }

    def __init__(
        self_,
        public_id: str,
        allow_insecure_certificates: Union[bool, UnsetType] = unset,
        basic_auth: Union[
            SyntheticsBasicAuth,
            SyntheticsBasicAuthWeb,
            SyntheticsBasicAuthSigv4,
            SyntheticsBasicAuthNTLM,
            SyntheticsBasicAuthDigest,
            SyntheticsBasicAuthOauthClient,
            SyntheticsBasicAuthOauthROP,
            UnsetType,
        ] = unset,
        body: Union[str, UnsetType] = unset,
        body_type: Union[str, UnsetType] = unset,
        cookies: Union[str, UnsetType] = unset,
        device_ids: Union[List[SyntheticsDeviceID], UnsetType] = unset,
        follow_redirects: Union[bool, UnsetType] = unset,
        headers: Union[SyntheticsTestHeaders, UnsetType] = unset,
        locations: Union[List[str], UnsetType] = unset,
        metadata: Union[SyntheticsCIBatchMetadata, UnsetType] = unset,
        retry: Union[SyntheticsTestOptionsRetry, UnsetType] = unset,
        start_url: Union[str, UnsetType] = unset,
        variables: Union[Dict[str, str], UnsetType] = unset,
        **kwargs,
    ):
        """
        Test configuration for Synthetics CI

        :param allow_insecure_certificates: Disable certificate checks in API tests.
        :type allow_insecure_certificates: bool, optional

        :param basic_auth: Object to handle basic authentication when performing the test.
        :type basic_auth: SyntheticsBasicAuth, optional

        :param body: Body to include in the test.
        :type body: str, optional

        :param body_type: Type of the data sent in a synthetics API test.
        :type body_type: str, optional

        :param cookies: Cookies for the request.
        :type cookies: str, optional

        :param device_ids: For browser test, array with the different device IDs used to run the test.
        :type device_ids: [SyntheticsDeviceID], optional

        :param follow_redirects: For API HTTP test, whether or not the test should follow redirects.
        :type follow_redirects: bool, optional

        :param headers: Headers to include when performing the test.
        :type headers: SyntheticsTestHeaders, optional

        :param locations: Array of locations used to run the test.
        :type locations: [str], optional

        :param metadata: Metadata for the Synthetics tests run.
        :type metadata: SyntheticsCIBatchMetadata, optional

        :param public_id: The public ID of the Synthetics test to trigger.
        :type public_id: str

        :param retry: Object describing the retry strategy to apply to a Synthetic test.
        :type retry: SyntheticsTestOptionsRetry, optional

        :param start_url: Starting URL for the browser test.
        :type start_url: str, optional

        :param variables: Variables to replace in the test.
        :type variables: {str: (str,)}, optional
        """
        if allow_insecure_certificates is not unset:
            kwargs["allow_insecure_certificates"] = allow_insecure_certificates
        if basic_auth is not unset:
            kwargs["basic_auth"] = basic_auth
        if body is not unset:
            kwargs["body"] = body
        if body_type is not unset:
            kwargs["body_type"] = body_type
        if cookies is not unset:
            kwargs["cookies"] = cookies
        if device_ids is not unset:
            kwargs["device_ids"] = device_ids
        if follow_redirects is not unset:
            kwargs["follow_redirects"] = follow_redirects
        if headers is not unset:
            kwargs["headers"] = headers
        if locations is not unset:
            kwargs["locations"] = locations
        if metadata is not unset:
            kwargs["metadata"] = metadata
        if retry is not unset:
            kwargs["retry"] = retry
        if start_url is not unset:
            kwargs["start_url"] = start_url
        if variables is not unset:
            kwargs["variables"] = variables
        super().__init__(kwargs)

        self_.public_id = public_id



"""
Search for SLOs returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.service_level_objectives_api import ServiceLevelObjectivesApi

# there is a valid "slo" in the system
SLO_DATA_0_NAME = environ["SLO_DATA_0_NAME"]

configuration = Configuration()
configuration.unstable_operations["search_slo"] = True
with ApiClient(configuration) as api_client:
    api_instance = ServiceLevelObjectivesApi(api_client)
    response = api_instance.search_slo(
        query=SLO_DATA_0_NAME,
        page_size=20,
        page_number=0,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.rum_bucket_response import RUMBucketResponse


class RUMAggregationBucketsResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.rum_bucket_response import RUMBucketResponse

        return {
            "buckets": ([RUMBucketResponse],),
        }

    attribute_map = {
        "buckets": "buckets",
    }

    def __init__(self_, buckets: Union[List[RUMBucketResponse], UnsetType] = unset, **kwargs):
        """
        The query results.

        :param buckets: The list of matching buckets, one item per bucket.
        :type buckets: [RUMBucketResponse], optional
        """
        if buckets is not unset:
            kwargs["buckets"] = buckets
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.security_monitoring_triage_user import SecurityMonitoringTriageUser
    from datadog_api_client.v2.model.security_monitoring_signal_archive_reason import (
        SecurityMonitoringSignalArchiveReason,
    )
    from datadog_api_client.v2.model.security_monitoring_signal_incident_ids import SecurityMonitoringSignalIncidentIds
    from datadog_api_client.v2.model.security_monitoring_signal_state import SecurityMonitoringSignalState


class SecurityMonitoringSignalTriageAttributes(ModelNormal):
    validations = {
        "archive_comment_timestamp": {
            "inclusive_minimum": 0,
        },
        "state_update_timestamp": {
            "inclusive_minimum": 0,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.security_monitoring_triage_user import SecurityMonitoringTriageUser
        from datadog_api_client.v2.model.security_monitoring_signal_archive_reason import (
            SecurityMonitoringSignalArchiveReason,
        )
        from datadog_api_client.v2.model.security_monitoring_signal_incident_ids import (
            SecurityMonitoringSignalIncidentIds,
        )
        from datadog_api_client.v2.model.security_monitoring_signal_state import SecurityMonitoringSignalState

        return {
            "archive_comment": (str,),
            "archive_comment_timestamp": (int,),
            "archive_comment_user": (SecurityMonitoringTriageUser,),
            "archive_reason": (SecurityMonitoringSignalArchiveReason,),
            "assignee": (SecurityMonitoringTriageUser,),
            "incident_ids": (SecurityMonitoringSignalIncidentIds,),
            "state": (SecurityMonitoringSignalState,),
            "state_update_timestamp": (int,),
            "state_update_user": (SecurityMonitoringTriageUser,),
        }

    attribute_map = {
        "archive_comment": "archive_comment",
        "archive_comment_timestamp": "archive_comment_timestamp",
        "archive_comment_user": "archive_comment_user",
        "archive_reason": "archive_reason",
        "assignee": "assignee",
        "incident_ids": "incident_ids",
        "state": "state",
        "state_update_timestamp": "state_update_timestamp",
        "state_update_user": "state_update_user",
    }

    def __init__(
        self_,
        assignee: SecurityMonitoringTriageUser,
        incident_ids: SecurityMonitoringSignalIncidentIds,
        state: SecurityMonitoringSignalState,
        archive_comment: Union[str, UnsetType] = unset,
        archive_comment_timestamp: Union[int, UnsetType] = unset,
        archive_comment_user: Union[SecurityMonitoringTriageUser, UnsetType] = unset,
        archive_reason: Union[SecurityMonitoringSignalArchiveReason, UnsetType] = unset,
        state_update_timestamp: Union[int, UnsetType] = unset,
        state_update_user: Union[SecurityMonitoringTriageUser, UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes describing a triage state update operation over a security signal.

        :param archive_comment: Optional comment to display on archived signals.
        :type archive_comment: str, optional

        :param archive_comment_timestamp: Timestamp of the last edit to the comment.
        :type archive_comment_timestamp: int, optional

        :param archive_comment_user: Object representing a given user entity.
        :type archive_comment_user: SecurityMonitoringTriageUser, optional

        :param archive_reason: Reason a signal is archived.
        :type archive_reason: SecurityMonitoringSignalArchiveReason, optional

        :param assignee: Object representing a given user entity.
        :type assignee: SecurityMonitoringTriageUser

        :param incident_ids: Array of incidents that are associated with this signal.
        :type incident_ids: SecurityMonitoringSignalIncidentIds

        :param state: The new triage state of the signal.
        :type state: SecurityMonitoringSignalState

        :param state_update_timestamp: Timestamp of the last update to the signal state.
        :type state_update_timestamp: int, optional

        :param state_update_user: Object representing a given user entity.
        :type state_update_user: SecurityMonitoringTriageUser, optional
        """
        if archive_comment is not unset:
            kwargs["archive_comment"] = archive_comment
        if archive_comment_timestamp is not unset:
            kwargs["archive_comment_timestamp"] = archive_comment_timestamp
        if archive_comment_user is not unset:
            kwargs["archive_comment_user"] = archive_comment_user
        if archive_reason is not unset:
            kwargs["archive_reason"] = archive_reason
        if state_update_timestamp is not unset:
            kwargs["state_update_timestamp"] = state_update_timestamp
        if state_update_user is not unset:
            kwargs["state_update_user"] = state_update_user
        super().__init__(kwargs)

        self_.assignee = assignee
        self_.incident_ids = incident_ids
        self_.state = state



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_assertion import SyntheticsAssertion
    from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
    from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
    from datadog_api_client.v1.model.synthetics_browser_variable import SyntheticsBrowserVariable
    from datadog_api_client.v1.model.synthetics_assertion_target import SyntheticsAssertionTarget
    from datadog_api_client.v1.model.synthetics_assertion_json_path_target import SyntheticsAssertionJSONPathTarget
    from datadog_api_client.v1.model.synthetics_assertion_x_path_target import SyntheticsAssertionXPathTarget


class SyntheticsTestConfig(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_assertion import SyntheticsAssertion
        from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
        from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
        from datadog_api_client.v1.model.synthetics_browser_variable import SyntheticsBrowserVariable

        return {
            "assertions": ([SyntheticsAssertion],),
            "config_variables": ([SyntheticsConfigVariable],),
            "request": (SyntheticsTestRequest,),
            "variables": ([SyntheticsBrowserVariable],),
        }

    attribute_map = {
        "assertions": "assertions",
        "config_variables": "configVariables",
        "request": "request",
        "variables": "variables",
    }

    def __init__(
        self_,
        assertions: Union[
            List[
                Union[
                    SyntheticsAssertion,
                    SyntheticsAssertionTarget,
                    SyntheticsAssertionJSONPathTarget,
                    SyntheticsAssertionXPathTarget,
                ]
            ],
            UnsetType,
        ] = unset,
        config_variables: Union[List[SyntheticsConfigVariable], UnsetType] = unset,
        request: Union[SyntheticsTestRequest, UnsetType] = unset,
        variables: Union[List[SyntheticsBrowserVariable], UnsetType] = unset,
        **kwargs,
    ):
        """
        Configuration object for a Synthetic test.

        :param assertions: Array of assertions used for the test. Required for single API tests.
        :type assertions: [SyntheticsAssertion], optional

        :param config_variables: Array of variables used for the test.
        :type config_variables: [SyntheticsConfigVariable], optional

        :param request: Object describing the Synthetic test request.
        :type request: SyntheticsTestRequest, optional

        :param variables: Browser tests only - array of variables used for the test steps.
        :type variables: [SyntheticsBrowserVariable], optional
        """
        if assertions is not unset:
            kwargs["assertions"] = assertions
        if config_variables is not unset:
            kwargs["config_variables"] = config_variables
        if request is not unset:
            kwargs["request"] = request
        if variables is not unset:
            kwargs["variables"] = variables
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_test_config import SyntheticsTestConfig


class SyntheticsBrowserTestResultFullCheck(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_test_config import SyntheticsTestConfig

        return {
            "config": (SyntheticsTestConfig,),
        }

    attribute_map = {
        "config": "config",
    }

    def __init__(self_, config: SyntheticsTestConfig, **kwargs):
        """
        Object describing the browser test configuration.

        :param config: Configuration object for a Synthetic test.
        :type config: SyntheticsTestConfig
        """
        super().__init__(kwargs)

        self_.config = config



"""
Search logs returns "OK" response with pagination
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.logs_api import LogsApi
from datadog_api_client.v2.model.logs_list_request import LogsListRequest
from datadog_api_client.v2.model.logs_list_request_page import LogsListRequestPage
from datadog_api_client.v2.model.logs_query_filter import LogsQueryFilter
from datadog_api_client.v2.model.logs_query_options import LogsQueryOptions
from datadog_api_client.v2.model.logs_sort import LogsSort

body = LogsListRequest(
    filter=LogsQueryFilter(
        _from="now-15m",
        indexes=[
            "main",
        ],
        to="now",
    ),
    options=LogsQueryOptions(
        timezone="GMT",
    ),
    page=LogsListRequestPage(
        limit=2,
    ),
    sort=LogsSort.TIMESTAMP_ASCENDING,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsApi(api_client)
    items = api_instance.list_logs_with_pagination(body=body)
    for item in items:
        print(item)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_ci_batch_metadata import SyntheticsCIBatchMetadata


class SyntheticsTriggerTest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_ci_batch_metadata import SyntheticsCIBatchMetadata

        return {
            "metadata": (SyntheticsCIBatchMetadata,),
            "public_id": (str,),
        }

    attribute_map = {
        "metadata": "metadata",
        "public_id": "public_id",
    }

    def __init__(self_, public_id: str, metadata: Union[SyntheticsCIBatchMetadata, UnsetType] = unset, **kwargs):
        """
        Test configuration for Synthetics

        :param metadata: Metadata for the Synthetics tests run.
        :type metadata: SyntheticsCIBatchMetadata, optional

        :param public_id: The public ID of the Synthetics test to trigger.
        :type public_id: str
        """
        if metadata is not unset:
            kwargs["metadata"] = metadata
        super().__init__(kwargs)

        self_.public_id = public_id



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.sensitive_data_scanner_filter import SensitiveDataScannerFilter
    from datadog_api_client.v2.model.sensitive_data_scanner_product import SensitiveDataScannerProduct


class SensitiveDataScannerGroupAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.sensitive_data_scanner_filter import SensitiveDataScannerFilter
        from datadog_api_client.v2.model.sensitive_data_scanner_product import SensitiveDataScannerProduct

        return {
            "description": (str,),
            "filter": (SensitiveDataScannerFilter,),
            "is_enabled": (bool,),
            "name": (str,),
            "product_list": ([SensitiveDataScannerProduct],),
        }

    attribute_map = {
        "description": "description",
        "filter": "filter",
        "is_enabled": "is_enabled",
        "name": "name",
        "product_list": "product_list",
    }

    def __init__(
        self_,
        description: Union[str, UnsetType] = unset,
        filter: Union[SensitiveDataScannerFilter, UnsetType] = unset,
        is_enabled: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        product_list: Union[List[SensitiveDataScannerProduct], UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes of the Sensitive Data Scanner group.

        :param description: Description of the group.
        :type description: str, optional

        :param filter: Filter for the Scanning Group.
        :type filter: SensitiveDataScannerFilter, optional

        :param is_enabled: Whether or not the group is enabled.
        :type is_enabled: bool, optional

        :param name: Name of the group.
        :type name: str, optional

        :param product_list: List of products the scanning group applies.
        :type product_list: [SensitiveDataScannerProduct], optional
        """
        if description is not unset:
            kwargs["description"] = description
        if filter is not unset:
            kwargs["filter"] = filter
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if name is not unset:
            kwargs["name"] = name
        if product_list is not unset:
            kwargs["product_list"] = product_list
        super().__init__(kwargs)



"""
Delete an API key returns "No Content" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.key_management_api import KeyManagementApi

# there is a valid "api_key" in the system
API_KEY_DATA_ID = environ["API_KEY_DATA_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = KeyManagementApi(api_client)
    api_instance.delete_api_key(
        api_key_id=API_KEY_DATA_ID,
    )



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class UsageCWSHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "cws_container_count": (int,),
            "cws_host_count": (int,),
            "hour": (datetime,),
            "org_name": (str,),
            "public_id": (str,),
        }

    attribute_map = {
        "cws_container_count": "cws_container_count",
        "cws_host_count": "cws_host_count",
        "hour": "hour",
        "org_name": "org_name",
        "public_id": "public_id",
    }

    def __init__(
        self_,
        cws_container_count: Union[int, UnsetType] = unset,
        cws_host_count: Union[int, UnsetType] = unset,
        hour: Union[datetime, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Cloud Workload Security usage for a given organization for a given hour.

        :param cws_container_count: The total number of Cloud Workload Security container hours from the start of the given hour’s month until the given hour.
        :type cws_container_count: int, optional

        :param cws_host_count: The total number of Cloud Workload Security host hours from the start of the given hour’s month until the given hour.
        :type cws_host_count: int, optional

        :param hour: The hour for the usage.
        :type hour: datetime, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional
        """
        if cws_container_count is not unset:
            kwargs["cws_container_count"] = cws_container_count
        if cws_host_count is not unset:
            kwargs["cws_host_count"] = cws_host_count
        if hour is not unset:
            kwargs["hour"] = hour
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        super().__init__(kwargs)



"""
Delete Scanning Group returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.sensitive_data_scanner_api import SensitiveDataScannerApi
from datadog_api_client.v2.model.sensitive_data_scanner_group_delete_request import (
    SensitiveDataScannerGroupDeleteRequest,
)
from datadog_api_client.v2.model.sensitive_data_scanner_meta_version_only import SensitiveDataScannerMetaVersionOnly

# there is a valid "scanning_group" in the system
GROUP_DATA_ID = environ["GROUP_DATA_ID"]

body = SensitiveDataScannerGroupDeleteRequest(
    meta=SensitiveDataScannerMetaVersionOnly(),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SensitiveDataScannerApi(api_client)
    response = api_instance.delete_scanning_group(group_id=GROUP_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class LogsExclusionFilter(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "query": (str,),
            "sample_rate": (float,),
        }

    attribute_map = {
        "query": "query",
        "sample_rate": "sample_rate",
    }

    def __init__(self_, sample_rate: float, query: Union[str, UnsetType] = unset, **kwargs):
        """
        Exclusion filter is defined by a query, a sampling rule, and a active/inactive toggle.

        :param query: Default query is ``*`` , meaning all logs flowing in the index would be excluded.
            Scope down exclusion filter to only a subset of logs with a log query.
        :type query: str, optional

        :param sample_rate: Sample rate to apply to logs going through this exclusion filter,
            a value of 1.0 excludes all logs matching the query.
        :type sample_rate: float
        """
        if query is not unset:
            kwargs["query"] = query
        super().__init__(kwargs)

        self_.sample_rate = sample_rate



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class EventAlertType(ModelSimple):
    """
    If an alert event is enabled, set its type.
        For example, `error`, `warning`, `info`, `success`, `user_update`,
        `recommendation`, and `snapshot`.

    :param value: Must be one of ["error", "warning", "info", "success", "user_update", "recommendation", "snapshot"].
    :type value: str
    """

    allowed_values = {
        "error",
        "warning",
        "info",
        "success",
        "user_update",
        "recommendation",
        "snapshot",
    }
    ERROR: ClassVar["EventAlertType"]
    WARNING: ClassVar["EventAlertType"]
    INFO: ClassVar["EventAlertType"]
    SUCCESS: ClassVar["EventAlertType"]
    USER_UPDATE: ClassVar["EventAlertType"]
    RECOMMENDATION: ClassVar["EventAlertType"]
    SNAPSHOT: ClassVar["EventAlertType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


EventAlertType.ERROR = EventAlertType("error")
EventAlertType.WARNING = EventAlertType("warning")
EventAlertType.INFO = EventAlertType("info")
EventAlertType.SUCCESS = EventAlertType("success")
EventAlertType.USER_UPDATE = EventAlertType("user_update")
EventAlertType.RECOMMENDATION = EventAlertType("recommendation")
EventAlertType.SNAPSHOT = EventAlertType("snapshot")



# Unless explicitly stated otherwise all files in this repository are licensed
# under the 3-clause BSD style license (see LICENSE).
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2020-Present Datadog, Inc.

__version__ = "2.8.0"



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class AWSAccountAndLambdaRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "account_id": (str,),
            "lambda_arn": (str,),
        }

    attribute_map = {
        "account_id": "account_id",
        "lambda_arn": "lambda_arn",
    }

    def __init__(self_, account_id: str, lambda_arn: str, **kwargs):
        """
        AWS account ID and Lambda ARN.

        :param account_id: Your AWS Account ID without dashes.
        :type account_id: str

        :param lambda_arn: ARN of the Datadog Lambda created during the Datadog-Amazon Web services Log collection setup.
        :type lambda_arn: str
        """
        super().__init__(kwargs)

        self_.account_id = account_id
        self_.lambda_arn = lambda_arn



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.log import Log


class LogsListResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.log import Log

        return {
            "logs": ([Log],),
            "next_log_id": (str,),
            "status": (str,),
        }

    attribute_map = {
        "logs": "logs",
        "next_log_id": "nextLogId",
        "status": "status",
    }

    def __init__(
        self_,
        logs: Union[List[Log], UnsetType] = unset,
        next_log_id: Union[str, UnsetType] = unset,
        status: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Response object with all logs matching the request and pagination information.

        :param logs: Array of logs matching the request and the ``nextLogId`` if sent.
        :type logs: [Log], optional

        :param next_log_id: Hash identifier of the next log to return in the list.
            This parameter is used for the pagination feature.
        :type next_log_id: str, optional

        :param status: Status of the response.
        :type status: str, optional
        """
        if logs is not unset:
            kwargs["logs"] = logs
        if next_log_id is not unset:
            kwargs["next_log_id"] = next_log_id
        if status is not unset:
            kwargs["status"] = status
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.sensitive_data_scanner_group_attributes import SensitiveDataScannerGroupAttributes
    from datadog_api_client.v2.model.sensitive_data_scanner_group_relationships import (
        SensitiveDataScannerGroupRelationships,
    )
    from datadog_api_client.v2.model.sensitive_data_scanner_group_type import SensitiveDataScannerGroupType


class SensitiveDataScannerGroupCreate(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.sensitive_data_scanner_group_attributes import (
            SensitiveDataScannerGroupAttributes,
        )
        from datadog_api_client.v2.model.sensitive_data_scanner_group_relationships import (
            SensitiveDataScannerGroupRelationships,
        )
        from datadog_api_client.v2.model.sensitive_data_scanner_group_type import SensitiveDataScannerGroupType

        return {
            "attributes": (SensitiveDataScannerGroupAttributes,),
            "relationships": (SensitiveDataScannerGroupRelationships,),
            "type": (SensitiveDataScannerGroupType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "relationships": "relationships",
        "type": "type",
    }

    def __init__(
        self_,
        attributes: SensitiveDataScannerGroupAttributes,
        type: SensitiveDataScannerGroupType,
        relationships: Union[SensitiveDataScannerGroupRelationships, UnsetType] = unset,
        **kwargs,
    ):
        """
        Data related to the creation of a group.

        :param attributes: Attributes of the Sensitive Data Scanner group.
        :type attributes: SensitiveDataScannerGroupAttributes

        :param relationships: Relationships of the group.
        :type relationships: SensitiveDataScannerGroupRelationships, optional

        :param type: Sensitive Data Scanner group type.
        :type type: SensitiveDataScannerGroupType
        """
        if relationships is not unset:
            kwargs["relationships"] = relationships
        super().__init__(kwargs)

        self_.attributes = attributes
        self_.type = type



"""
Update Scanning Group returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.sensitive_data_scanner_api import SensitiveDataScannerApi
from datadog_api_client.v2.model.sensitive_data_scanner_configuration import SensitiveDataScannerConfiguration
from datadog_api_client.v2.model.sensitive_data_scanner_configuration_data import SensitiveDataScannerConfigurationData
from datadog_api_client.v2.model.sensitive_data_scanner_configuration_type import SensitiveDataScannerConfigurationType
from datadog_api_client.v2.model.sensitive_data_scanner_filter import SensitiveDataScannerFilter
from datadog_api_client.v2.model.sensitive_data_scanner_group_attributes import SensitiveDataScannerGroupAttributes
from datadog_api_client.v2.model.sensitive_data_scanner_group_relationships import (
    SensitiveDataScannerGroupRelationships,
)
from datadog_api_client.v2.model.sensitive_data_scanner_group_type import SensitiveDataScannerGroupType
from datadog_api_client.v2.model.sensitive_data_scanner_group_update import SensitiveDataScannerGroupUpdate
from datadog_api_client.v2.model.sensitive_data_scanner_group_update_request import (
    SensitiveDataScannerGroupUpdateRequest,
)
from datadog_api_client.v2.model.sensitive_data_scanner_meta_version_only import SensitiveDataScannerMetaVersionOnly
from datadog_api_client.v2.model.sensitive_data_scanner_product import SensitiveDataScannerProduct
from datadog_api_client.v2.model.sensitive_data_scanner_rule_data import SensitiveDataScannerRuleData

# there is a valid "scanning_group" in the system
GROUP_DATA_ID = environ["GROUP_DATA_ID"]

# a valid "configuration" in the system
CONFIGURATION_DATA_ID = environ["CONFIGURATION_DATA_ID"]

body = SensitiveDataScannerGroupUpdateRequest(
    meta=SensitiveDataScannerMetaVersionOnly(),
    data=SensitiveDataScannerGroupUpdate(
        id=GROUP_DATA_ID,
        type=SensitiveDataScannerGroupType.SENSITIVE_DATA_SCANNER_GROUP,
        attributes=SensitiveDataScannerGroupAttributes(
            name="Example-Update_Scanning_Group_returns_OK_response",
            is_enabled=False,
            product_list=[
                SensitiveDataScannerProduct.LOGS,
            ],
            filter=SensitiveDataScannerFilter(
                query="*",
            ),
        ),
        relationships=SensitiveDataScannerGroupRelationships(
            configuration=SensitiveDataScannerConfigurationData(
                data=SensitiveDataScannerConfiguration(
                    type=SensitiveDataScannerConfigurationType.SENSITIVE_DATA_SCANNER_CONFIGURATIONS,
                    id=CONFIGURATION_DATA_ID,
                ),
            ),
            rules=SensitiveDataScannerRuleData(
                data=[],
            ),
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SensitiveDataScannerApi(api_client)
    response = api_instance.update_scanning_group(group_id=GROUP_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class IncidentAttachmentLinkAttributesAttachmentObject(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "document_url": (str,),
            "title": (str,),
        }

    attribute_map = {
        "document_url": "documentUrl",
        "title": "title",
    }

    def __init__(self_, document_url: str, title: str, **kwargs):
        """
        The link attachment.

        :param document_url: The URL of this link attachment.
        :type document_url: str

        :param title: The title of this link attachment.
        :type title: str
        """
        super().__init__(kwargs)

        self_.document_url = document_url
        self_.title = title



"""
Update a Slack integration channel returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.slack_integration_api import SlackIntegrationApi
from datadog_api_client.v1.model.slack_integration_channel import SlackIntegrationChannel
from datadog_api_client.v1.model.slack_integration_channel_display import SlackIntegrationChannelDisplay

body = SlackIntegrationChannel(
    display=SlackIntegrationChannelDisplay(
        message=True,
        notified=True,
        snapshot=True,
        tags=True,
    ),
    name="#general",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SlackIntegrationApi(api_client)
    response = api_instance.update_slack_integration_channel(
        account_name="account_name", channel_name="channel_name", body=body
    )

    print(response)



"""
Get a Slack integration channel returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.slack_integration_api import SlackIntegrationApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SlackIntegrationApi(api_client)
    response = api_instance.get_slack_integration_channel(
        account_name="account_name",
        channel_name="channel_name",
    )

    print(response)



"""
Create a new incident service returns "CREATED" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.incident_services_api import IncidentServicesApi
from datadog_api_client.v2.model.incident_service_create_attributes import IncidentServiceCreateAttributes
from datadog_api_client.v2.model.incident_service_create_data import IncidentServiceCreateData
from datadog_api_client.v2.model.incident_service_create_request import IncidentServiceCreateRequest
from datadog_api_client.v2.model.incident_service_type import IncidentServiceType

body = IncidentServiceCreateRequest(
    data=IncidentServiceCreateData(
        type=IncidentServiceType.SERVICES,
        attributes=IncidentServiceCreateAttributes(
            name="Example-Create_a_new_incident_service_returns_CREATED_response",
        ),
    ),
)

configuration = Configuration()
configuration.unstable_operations["create_incident_service"] = True
with ApiClient(configuration) as api_client:
    api_instance = IncidentServicesApi(api_client)
    response = api_instance.create_incident_service(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SensitiveDataScannerTextReplacementType(ModelSimple):
    """
    Type of the replacement text. None means no replacement.
        hash means the data will be stubbed. replacement_string means that
        one can chose a text to replace the data. partial_replacement_from_beginning
        allows a user to partially replace the data from the beginning, and
        partial_replacement_from_end on the other hand, allows to replace data from
        the end.

    :param value: If omitted defaults to "none". Must be one of ["none", "hash", "replacement_string", "partial_replacement_from_beginning", "partial_replacement_from_end"].
    :type value: str
    """

    allowed_values = {
        "none",
        "hash",
        "replacement_string",
        "partial_replacement_from_beginning",
        "partial_replacement_from_end",
    }
    NONE: ClassVar["SensitiveDataScannerTextReplacementType"]
    HASH: ClassVar["SensitiveDataScannerTextReplacementType"]
    REPLACEMENT_STRING: ClassVar["SensitiveDataScannerTextReplacementType"]
    PARTIAL_REPLACEMENT_FROM_BEGINNING: ClassVar["SensitiveDataScannerTextReplacementType"]
    PARTIAL_REPLACEMENT_FROM_END: ClassVar["SensitiveDataScannerTextReplacementType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SensitiveDataScannerTextReplacementType.NONE = SensitiveDataScannerTextReplacementType("none")
SensitiveDataScannerTextReplacementType.HASH = SensitiveDataScannerTextReplacementType("hash")
SensitiveDataScannerTextReplacementType.REPLACEMENT_STRING = SensitiveDataScannerTextReplacementType(
    "replacement_string"
)
SensitiveDataScannerTextReplacementType.PARTIAL_REPLACEMENT_FROM_BEGINNING = SensitiveDataScannerTextReplacementType(
    "partial_replacement_from_beginning"
)
SensitiveDataScannerTextReplacementType.PARTIAL_REPLACEMENT_FROM_END = SensitiveDataScannerTextReplacementType(
    "partial_replacement_from_end"
)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    none_type,
    unset,
    UnsetType,
)


class UserAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "created_at": (datetime,),
            "disabled": (bool,),
            "email": (str,),
            "handle": (str,),
            "icon": (str,),
            "modified_at": (datetime,),
            "name": (str, none_type),
            "service_account": (bool,),
            "status": (str,),
            "title": (str, none_type),
            "verified": (bool,),
        }

    attribute_map = {
        "created_at": "created_at",
        "disabled": "disabled",
        "email": "email",
        "handle": "handle",
        "icon": "icon",
        "modified_at": "modified_at",
        "name": "name",
        "service_account": "service_account",
        "status": "status",
        "title": "title",
        "verified": "verified",
    }

    def __init__(
        self_,
        created_at: Union[datetime, UnsetType] = unset,
        disabled: Union[bool, UnsetType] = unset,
        email: Union[str, UnsetType] = unset,
        handle: Union[str, UnsetType] = unset,
        icon: Union[str, UnsetType] = unset,
        modified_at: Union[datetime, UnsetType] = unset,
        name: Union[str, none_type, UnsetType] = unset,
        service_account: Union[bool, UnsetType] = unset,
        status: Union[str, UnsetType] = unset,
        title: Union[str, none_type, UnsetType] = unset,
        verified: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Attributes of user object returned by the API.

        :param created_at: Creation time of the user.
        :type created_at: datetime, optional

        :param disabled: Whether the user is disabled.
        :type disabled: bool, optional

        :param email: Email of the user.
        :type email: str, optional

        :param handle: Handle of the user.
        :type handle: str, optional

        :param icon: URL of the user's icon.
        :type icon: str, optional

        :param modified_at: Time that the user was last modified.
        :type modified_at: datetime, optional

        :param name: Name of the user.
        :type name: str, none_type, optional

        :param service_account: Whether the user is a service account.
        :type service_account: bool, optional

        :param status: Status of the user.
        :type status: str, optional

        :param title: Title of the user.
        :type title: str, none_type, optional

        :param verified: Whether the user is verified.
        :type verified: bool, optional
        """
        if created_at is not unset:
            kwargs["created_at"] = created_at
        if disabled is not unset:
            kwargs["disabled"] = disabled
        if email is not unset:
            kwargs["email"] = email
        if handle is not unset:
            kwargs["handle"] = handle
        if icon is not unset:
            kwargs["icon"] = icon
        if modified_at is not unset:
            kwargs["modified_at"] = modified_at
        if name is not unset:
            kwargs["name"] = name
        if service_account is not unset:
            kwargs["service_account"] = service_account
        if status is not unset:
            kwargs["status"] = status
        if title is not unset:
            kwargs["title"] = title
        if verified is not unset:
            kwargs["verified"] = verified
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    date,
    datetime,
    none_type,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.service_definition_v2_contact import ServiceDefinitionV2Contact
    from datadog_api_client.v2.model.service_definition_v2_doc import ServiceDefinitionV2Doc
    from datadog_api_client.v2.model.service_definition_v2_integrations import ServiceDefinitionV2Integrations
    from datadog_api_client.v2.model.service_definition_v2_link import ServiceDefinitionV2Link
    from datadog_api_client.v2.model.service_definition_v2_repo import ServiceDefinitionV2Repo
    from datadog_api_client.v2.model.service_definition_v2_version import ServiceDefinitionV2Version
    from datadog_api_client.v2.model.service_definition_v2_email import ServiceDefinitionV2Email
    from datadog_api_client.v2.model.service_definition_v2_slack import ServiceDefinitionV2Slack


class ServiceDefinitionV2(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.service_definition_v2_contact import ServiceDefinitionV2Contact
        from datadog_api_client.v2.model.service_definition_v2_doc import ServiceDefinitionV2Doc
        from datadog_api_client.v2.model.service_definition_v2_integrations import ServiceDefinitionV2Integrations
        from datadog_api_client.v2.model.service_definition_v2_link import ServiceDefinitionV2Link
        from datadog_api_client.v2.model.service_definition_v2_repo import ServiceDefinitionV2Repo
        from datadog_api_client.v2.model.service_definition_v2_version import ServiceDefinitionV2Version

        return {
            "contacts": ([ServiceDefinitionV2Contact],),
            "dd_service": (str,),
            "dd_team": (str,),
            "docs": ([ServiceDefinitionV2Doc],),
            "extensions": (
                {
                    str: (
                        bool,
                        date,
                        datetime,
                        dict,
                        float,
                        int,
                        list,
                        str,
                        none_type,
                    )
                },
            ),
            "integrations": (ServiceDefinitionV2Integrations,),
            "links": ([ServiceDefinitionV2Link],),
            "repos": ([ServiceDefinitionV2Repo],),
            "schema_version": (ServiceDefinitionV2Version,),
            "tags": ([str],),
            "team": (str,),
        }

    attribute_map = {
        "contacts": "contacts",
        "dd_service": "dd-service",
        "dd_team": "dd-team",
        "docs": "docs",
        "extensions": "extensions",
        "integrations": "integrations",
        "links": "links",
        "repos": "repos",
        "schema_version": "schema-version",
        "tags": "tags",
        "team": "team",
    }

    def __init__(
        self_,
        dd_service: str,
        schema_version: ServiceDefinitionV2Version,
        contacts: Union[
            List[Union[ServiceDefinitionV2Contact, ServiceDefinitionV2Email, ServiceDefinitionV2Slack]], UnsetType
        ] = unset,
        dd_team: Union[str, UnsetType] = unset,
        docs: Union[List[ServiceDefinitionV2Doc], UnsetType] = unset,
        extensions: Union[Dict[str, Any], UnsetType] = unset,
        integrations: Union[ServiceDefinitionV2Integrations, UnsetType] = unset,
        links: Union[List[ServiceDefinitionV2Link], UnsetType] = unset,
        repos: Union[List[ServiceDefinitionV2Repo], UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        team: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Service definition V2 for providing service metadata and integrations.

        :param contacts: A list of contacts related to the services.
        :type contacts: [ServiceDefinitionV2Contact], optional

        :param dd_service: Unique identifier of the service. Must be unique across all services and is used to match with a service in Datadog.
        :type dd_service: str

        :param dd_team: Experimental feature. A Team handle that matches a Team in the Datadog Teams product.
        :type dd_team: str, optional

        :param docs: A list of documentation related to the services.
        :type docs: [ServiceDefinitionV2Doc], optional

        :param extensions: Extensions to V2 schema.
        :type extensions: {str: (bool, date, datetime, dict, float, int, list, str, none_type,)}, optional

        :param integrations: Third party integrations that Datadog supports.
        :type integrations: ServiceDefinitionV2Integrations, optional

        :param links: A list of links related to the services.
        :type links: [ServiceDefinitionV2Link], optional

        :param repos: A list of code repositories related to the services.
        :type repos: [ServiceDefinitionV2Repo], optional

        :param schema_version: Schema version being used.
        :type schema_version: ServiceDefinitionV2Version

        :param tags: A set of custom tags.
        :type tags: [str], optional

        :param team: Team that owns the service.
        :type team: str, optional
        """
        if contacts is not unset:
            kwargs["contacts"] = contacts
        if dd_team is not unset:
            kwargs["dd_team"] = dd_team
        if docs is not unset:
            kwargs["docs"] = docs
        if extensions is not unset:
            kwargs["extensions"] = extensions
        if integrations is not unset:
            kwargs["integrations"] = integrations
        if links is not unset:
            kwargs["links"] = links
        if repos is not unset:
            kwargs["repos"] = repos
        if tags is not unset:
            kwargs["tags"] = tags
        if team is not unset:
            kwargs["team"] = team
        super().__init__(kwargs)

        self_.dd_service = dd_service
        self_.schema_version = schema_version



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID


class SyntheticsDevice(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID

        return {
            "height": (int,),
            "id": (SyntheticsDeviceID,),
            "is_mobile": (bool,),
            "name": (str,),
            "width": (int,),
        }

    attribute_map = {
        "height": "height",
        "id": "id",
        "is_mobile": "isMobile",
        "name": "name",
        "width": "width",
    }

    def __init__(
        self_,
        height: int,
        id: SyntheticsDeviceID,
        name: str,
        width: int,
        is_mobile: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object describing the device used to perform the Synthetic test.

        :param height: Screen height of the device.
        :type height: int

        :param id: The device ID.
        :type id: SyntheticsDeviceID

        :param is_mobile: Whether or not the device is a mobile.
        :type is_mobile: bool, optional

        :param name: The device name.
        :type name: str

        :param width: Screen width of the device.
        :type width: int
        """
        if is_mobile is not unset:
            kwargs["is_mobile"] = is_mobile
        super().__init__(kwargs)

        self_.height = height
        self_.id = id
        self_.name = name
        self_.width = width



"""
Update a Cloud Workload Security Agent rule returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.cloud_workload_security_api import CloudWorkloadSecurityApi
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_type import CloudWorkloadSecurityAgentRuleType
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_attributes import (
    CloudWorkloadSecurityAgentRuleUpdateAttributes,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_data import (
    CloudWorkloadSecurityAgentRuleUpdateData,
)
from datadog_api_client.v2.model.cloud_workload_security_agent_rule_update_request import (
    CloudWorkloadSecurityAgentRuleUpdateRequest,
)

# there is a valid "agent_rule" in the system
AGENT_RULE_DATA_ID = environ["AGENT_RULE_DATA_ID"]

body = CloudWorkloadSecurityAgentRuleUpdateRequest(
    data=CloudWorkloadSecurityAgentRuleUpdateData(
        attributes=CloudWorkloadSecurityAgentRuleUpdateAttributes(
            description="Test Agent rule",
            enabled=True,
            expression='exec.file.name == "sh"',
        ),
        type=CloudWorkloadSecurityAgentRuleType.AGENT_RULE,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = CloudWorkloadSecurityApi(api_client)
    response = api_instance.update_cloud_workload_security_agent_rule(agent_rule_id=AGENT_RULE_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsAssertionType(ModelSimple):
    """
    Type of the assertion.

    :param value: Must be one of ["body", "header", "statusCode", "certificate", "responseTime", "property", "recordEvery", "recordSome", "tlsVersion", "minTlsVersion", "latency", "packetLossPercentage", "packetsReceived", "networkHop", "receivedMessage", "grpcHealthcheckStatus", "connection"].
    :type value: str
    """

    allowed_values = {
        "body",
        "header",
        "statusCode",
        "certificate",
        "responseTime",
        "property",
        "recordEvery",
        "recordSome",
        "tlsVersion",
        "minTlsVersion",
        "latency",
        "packetLossPercentage",
        "packetsReceived",
        "networkHop",
        "receivedMessage",
        "grpcHealthcheckStatus",
        "connection",
    }
    BODY: ClassVar["SyntheticsAssertionType"]
    HEADER: ClassVar["SyntheticsAssertionType"]
    STATUS_CODE: ClassVar["SyntheticsAssertionType"]
    CERTIFICATE: ClassVar["SyntheticsAssertionType"]
    RESPONSE_TIME: ClassVar["SyntheticsAssertionType"]
    PROPERTY: ClassVar["SyntheticsAssertionType"]
    RECORD_EVERY: ClassVar["SyntheticsAssertionType"]
    RECORD_SOME: ClassVar["SyntheticsAssertionType"]
    TLS_VERSION: ClassVar["SyntheticsAssertionType"]
    MIN_TLS_VERSION: ClassVar["SyntheticsAssertionType"]
    LATENCY: ClassVar["SyntheticsAssertionType"]
    PACKET_LOSS_PERCENTAGE: ClassVar["SyntheticsAssertionType"]
    PACKETS_RECEIVED: ClassVar["SyntheticsAssertionType"]
    NETWORK_HOP: ClassVar["SyntheticsAssertionType"]
    RECEIVED_MESSAGE: ClassVar["SyntheticsAssertionType"]
    GRPC_HEALTHCHECK_STATUS: ClassVar["SyntheticsAssertionType"]
    CONNECTION: ClassVar["SyntheticsAssertionType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsAssertionType.BODY = SyntheticsAssertionType("body")
SyntheticsAssertionType.HEADER = SyntheticsAssertionType("header")
SyntheticsAssertionType.STATUS_CODE = SyntheticsAssertionType("statusCode")
SyntheticsAssertionType.CERTIFICATE = SyntheticsAssertionType("certificate")
SyntheticsAssertionType.RESPONSE_TIME = SyntheticsAssertionType("responseTime")
SyntheticsAssertionType.PROPERTY = SyntheticsAssertionType("property")
SyntheticsAssertionType.RECORD_EVERY = SyntheticsAssertionType("recordEvery")
SyntheticsAssertionType.RECORD_SOME = SyntheticsAssertionType("recordSome")
SyntheticsAssertionType.TLS_VERSION = SyntheticsAssertionType("tlsVersion")
SyntheticsAssertionType.MIN_TLS_VERSION = SyntheticsAssertionType("minTlsVersion")
SyntheticsAssertionType.LATENCY = SyntheticsAssertionType("latency")
SyntheticsAssertionType.PACKET_LOSS_PERCENTAGE = SyntheticsAssertionType("packetLossPercentage")
SyntheticsAssertionType.PACKETS_RECEIVED = SyntheticsAssertionType("packetsReceived")
SyntheticsAssertionType.NETWORK_HOP = SyntheticsAssertionType("networkHop")
SyntheticsAssertionType.RECEIVED_MESSAGE = SyntheticsAssertionType("receivedMessage")
SyntheticsAssertionType.GRPC_HEALTHCHECK_STATUS = SyntheticsAssertionType("grpcHealthcheckStatus")
SyntheticsAssertionType.CONNECTION = SyntheticsAssertionType("connection")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.logs_archive_integration_s3 import LogsArchiveIntegrationS3
    from datadog_api_client.v2.model.logs_archive_destination_s3_type import LogsArchiveDestinationS3Type


class LogsArchiveDestinationS3(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.logs_archive_integration_s3 import LogsArchiveIntegrationS3
        from datadog_api_client.v2.model.logs_archive_destination_s3_type import LogsArchiveDestinationS3Type

        return {
            "bucket": (str,),
            "integration": (LogsArchiveIntegrationS3,),
            "path": (str,),
            "type": (LogsArchiveDestinationS3Type,),
        }

    attribute_map = {
        "bucket": "bucket",
        "integration": "integration",
        "path": "path",
        "type": "type",
    }

    def __init__(
        self_,
        bucket: str,
        integration: LogsArchiveIntegrationS3,
        type: LogsArchiveDestinationS3Type,
        path: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        The S3 archive destination.

        :param bucket: The bucket where the archive will be stored.
        :type bucket: str

        :param integration: The S3 Archive's integration destination.
        :type integration: LogsArchiveIntegrationS3

        :param path: The archive path.
        :type path: str, optional

        :param type: Type of the S3 archive destination.
        :type type: LogsArchiveDestinationS3Type
        """
        if path is not unset:
            kwargs["path"] = path
        super().__init__(kwargs)

        self_.bucket = bucket
        self_.integration = integration
        self_.type = type



"""
Create an API HTTP test returns "OK - Returns the created test details." response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
from datadog_api_client.v1.model.synthetics_api_test import SyntheticsAPITest
from datadog_api_client.v1.model.synthetics_api_test_config import SyntheticsAPITestConfig
from datadog_api_client.v1.model.synthetics_api_test_type import SyntheticsAPITestType
from datadog_api_client.v1.model.synthetics_assertion_json_path_operator import SyntheticsAssertionJSONPathOperator
from datadog_api_client.v1.model.synthetics_assertion_json_path_target import SyntheticsAssertionJSONPathTarget
from datadog_api_client.v1.model.synthetics_assertion_json_path_target_target import (
    SyntheticsAssertionJSONPathTargetTarget,
)
from datadog_api_client.v1.model.synthetics_assertion_operator import SyntheticsAssertionOperator
from datadog_api_client.v1.model.synthetics_assertion_target import SyntheticsAssertionTarget
from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType
from datadog_api_client.v1.model.synthetics_assertion_x_path_operator import SyntheticsAssertionXPathOperator
from datadog_api_client.v1.model.synthetics_assertion_x_path_target import SyntheticsAssertionXPathTarget
from datadog_api_client.v1.model.synthetics_assertion_x_path_target_target import SyntheticsAssertionXPathTargetTarget
from datadog_api_client.v1.model.synthetics_basic_auth_oauth_client import SyntheticsBasicAuthOauthClient
from datadog_api_client.v1.model.synthetics_basic_auth_oauth_client_type import SyntheticsBasicAuthOauthClientType
from datadog_api_client.v1.model.synthetics_basic_auth_oauth_token_api_authentication import (
    SyntheticsBasicAuthOauthTokenApiAuthentication,
)
from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
from datadog_api_client.v1.model.synthetics_config_variable_type import SyntheticsConfigVariableType
from datadog_api_client.v1.model.synthetics_test_details_sub_type import SyntheticsTestDetailsSubType
from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHeaders
from datadog_api_client.v1.model.synthetics_test_options import SyntheticsTestOptions
from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry
from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
from datadog_api_client.v1.model.synthetics_test_request_certificate import SyntheticsTestRequestCertificate
from datadog_api_client.v1.model.synthetics_test_request_certificate_item import SyntheticsTestRequestCertificateItem
from datadog_api_client.v1.model.synthetics_test_request_proxy import SyntheticsTestRequestProxy

body = SyntheticsAPITest(
    config=SyntheticsAPITestConfig(
        assertions=[
            SyntheticsAssertionTarget(
                operator=SyntheticsAssertionOperator.IS,
                _property="{{ PROPERTY }}",
                target="text/html",
                type=SyntheticsAssertionType.HEADER,
            ),
            SyntheticsAssertionTarget(
                operator=SyntheticsAssertionOperator.LESS_THAN,
                target=2000,
                type=SyntheticsAssertionType.RESPONSE_TIME,
            ),
            SyntheticsAssertionJSONPathTarget(
                operator=SyntheticsAssertionJSONPathOperator.VALIDATES_JSON_PATH,
                target=SyntheticsAssertionJSONPathTargetTarget(
                    json_path="topKey",
                    operator="isNot",
                    target_value="0",
                ),
                type=SyntheticsAssertionType.BODY,
            ),
            SyntheticsAssertionXPathTarget(
                operator=SyntheticsAssertionXPathOperator.VALIDATES_X_PATH,
                target=SyntheticsAssertionXPathTargetTarget(
                    x_path="target-xpath",
                    target_value="0",
                    operator="contains",
                ),
                type=SyntheticsAssertionType.BODY,
            ),
        ],
        config_variables=[
            SyntheticsConfigVariable(
                example="content-type",
                name="PROPERTY",
                pattern="content-type",
                type=SyntheticsConfigVariableType.TEXT,
            ),
        ],
        request=SyntheticsTestRequest(
            certificate=SyntheticsTestRequestCertificate(
                cert=SyntheticsTestRequestCertificateItem(
                    content="cert-content",
                    filename="cert-filename",
                    updated_at="2020-10-16T09:23:24.857Z",
                ),
                key=SyntheticsTestRequestCertificateItem(
                    content="key-content",
                    filename="key-filename",
                    updated_at="2020-10-16T09:23:24.857Z",
                ),
            ),
            headers=SyntheticsTestHeaders(
                unique="examplecreateanapihttptestreturnsokreturnsthecreatedtestdetailsresponse",
            ),
            method="GET",
            timeout=10.0,
            url="https://datadoghq.com",
            proxy=SyntheticsTestRequestProxy(
                url="https://datadoghq.com",
                headers=SyntheticsTestHeaders(),
            ),
            basic_auth=SyntheticsBasicAuthOauthClient(
                access_token_url="https://datadog-token.com",
                audience="audience",
                client_id="client-id",
                client_secret="client-secret",
                resource="resource",
                scope="yoyo",
                token_api_authentication=SyntheticsBasicAuthOauthTokenApiAuthentication.HEADER,
                type=SyntheticsBasicAuthOauthClientType.OAUTH_CLIENT,
            ),
        ),
    ),
    locations=[
        "aws:us-east-2",
    ],
    message="BDD test payload: synthetics_api_http_test_payload.json",
    name="Example-Create_an_API_HTTP_test_returns_OK_Returns_the_created_test_details_response",
    options=SyntheticsTestOptions(
        accept_self_signed=False,
        allow_insecure=True,
        follow_redirects=True,
        min_failure_duration=10,
        min_location_failed=1,
        monitor_name="Example-Create_an_API_HTTP_test_returns_OK_Returns_the_created_test_details_response",
        monitor_priority=5,
        retry=SyntheticsTestOptionsRetry(
            count=3,
            interval=10.0,
        ),
        tick_every=60,
    ),
    subtype=SyntheticsTestDetailsSubType.HTTP,
    tags=[
        "testing:api",
    ],
    type=SyntheticsAPITestType.API,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    response = api_instance.create_synthetics_api_test(body=body)

    print(response)



"""
Add a security signal to an incident returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.security_monitoring_api import SecurityMonitoringApi
from datadog_api_client.v1.model.add_signal_to_incident_request import AddSignalToIncidentRequest

body = AddSignalToIncidentRequest(
    incident_id=2609,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    response = api_instance.add_security_monitoring_signal_to_incident(
        signal_id="AQAAAYDiB_Ol8PbzFAAAAABBWURpQl9PbEFBQU0yeXhGTG9ZV2JnQUE", body=body
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class UsageCustomReportsAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "computed_on": (str,),
            "end_date": (str,),
            "size": (int,),
            "start_date": (str,),
            "tags": ([str],),
        }

    attribute_map = {
        "computed_on": "computed_on",
        "end_date": "end_date",
        "size": "size",
        "start_date": "start_date",
        "tags": "tags",
    }

    def __init__(
        self_,
        computed_on: Union[str, UnsetType] = unset,
        end_date: Union[str, UnsetType] = unset,
        size: Union[int, UnsetType] = unset,
        start_date: Union[str, UnsetType] = unset,
        tags: Union[List[str], UnsetType] = unset,
        **kwargs,
    ):
        """
        The response containing attributes for custom reports.

        :param computed_on: The date the specified custom report was computed.
        :type computed_on: str, optional

        :param end_date: The ending date of custom report.
        :type end_date: str, optional

        :param size: size
        :type size: int, optional

        :param start_date: The starting date of custom report.
        :type start_date: str, optional

        :param tags: A list of tags to apply to custom reports.
        :type tags: [str], optional
        """
        if computed_on is not unset:
            kwargs["computed_on"] = computed_on
        if end_date is not unset:
            kwargs["end_date"] = end_date
        if size is not unset:
            kwargs["size"] = size
        if start_date is not unset:
            kwargs["start_date"] = start_date
        if tags is not unset:
            kwargs["tags"] = tags
        super().__init__(kwargs)



"""
Create an API test with multi subtype returns "OK - Returns the created test details." response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
from datadog_api_client.v1.model.synthetics_api_step import SyntheticsAPIStep
from datadog_api_client.v1.model.synthetics_api_step_subtype import SyntheticsAPIStepSubtype
from datadog_api_client.v1.model.synthetics_api_test import SyntheticsAPITest
from datadog_api_client.v1.model.synthetics_api_test_config import SyntheticsAPITestConfig
from datadog_api_client.v1.model.synthetics_api_test_type import SyntheticsAPITestType
from datadog_api_client.v1.model.synthetics_assertion_operator import SyntheticsAssertionOperator
from datadog_api_client.v1.model.synthetics_assertion_target import SyntheticsAssertionTarget
from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType
from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
from datadog_api_client.v1.model.synthetics_config_variable_type import SyntheticsConfigVariableType
from datadog_api_client.v1.model.synthetics_global_variable_parse_test_options_type import (
    SyntheticsGlobalVariableParseTestOptionsType,
)
from datadog_api_client.v1.model.synthetics_global_variable_parser_type import SyntheticsGlobalVariableParserType
from datadog_api_client.v1.model.synthetics_parsing_options import SyntheticsParsingOptions
from datadog_api_client.v1.model.synthetics_test_details_sub_type import SyntheticsTestDetailsSubType
from datadog_api_client.v1.model.synthetics_test_options import SyntheticsTestOptions
from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry
from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
from datadog_api_client.v1.model.synthetics_variable_parser import SyntheticsVariableParser

body = SyntheticsAPITest(
    config=SyntheticsAPITestConfig(
        config_variables=[
            SyntheticsConfigVariable(
                example="content-type",
                name="PROPERTY",
                pattern="content-type",
                type=SyntheticsConfigVariableType.TEXT,
            ),
        ],
        steps=[
            SyntheticsAPIStep(
                allow_failure=True,
                assertions=[
                    SyntheticsAssertionTarget(
                        operator=SyntheticsAssertionOperator.IS,
                        type=SyntheticsAssertionType.STATUS_CODE,
                        target=200,
                    ),
                ],
                extracted_values=[
                    SyntheticsParsingOptions(
                        field="server",
                        name="EXTRACTED_VALUE",
                        parser=SyntheticsVariableParser(
                            type=SyntheticsGlobalVariableParserType.RAW,
                        ),
                        type=SyntheticsGlobalVariableParseTestOptionsType.HTTP_HEADER,
                    ),
                ],
                is_critical=True,
                name="request is sent",
                request=SyntheticsTestRequest(
                    method="GET",
                    timeout=10.0,
                    url="https://datadoghq.com",
                ),
                retry=SyntheticsTestOptionsRetry(
                    count=5,
                    interval=1000.0,
                ),
                subtype=SyntheticsAPIStepSubtype.HTTP,
            ),
        ],
    ),
    locations=[
        "aws:us-east-2",
    ],
    message="BDD test payload: synthetics_api_test_multi_step_payload.json",
    name="Example-Create_an_API_test_with_multi_subtype_returns_OK_Returns_the_created_test_details_response",
    options=SyntheticsTestOptions(
        accept_self_signed=False,
        allow_insecure=True,
        follow_redirects=True,
        min_failure_duration=10,
        min_location_failed=1,
        monitor_name="Example-Create_an_API_test_with_multi_subtype_returns_OK_Returns_the_created_test_details_response",
        monitor_priority=5,
        retry=SyntheticsTestOptionsRetry(
            count=3,
            interval=1000.0,
        ),
        tick_every=60,
    ),
    subtype=SyntheticsTestDetailsSubType.MULTI,
    tags=[
        "testing:api",
    ],
    type=SyntheticsAPITestType.API,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    response = api_instance.create_synthetics_api_test(body=body)

    print(response)



"""
Get all SLO corrections returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.service_level_objective_corrections_api import ServiceLevelObjectiveCorrectionsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceLevelObjectiveCorrectionsApi(api_client)
    response = api_instance.list_slo_correction(
        offset=1,
        limit=1,
    )

    print(response)



"""
Delete an existing rule returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.security_monitoring_api import SecurityMonitoringApi

# there is a valid "security_rule" in the system
SECURITY_RULE_ID = environ["SECURITY_RULE_ID"]

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SecurityMonitoringApi(api_client)
    api_instance.delete_security_monitoring_rule(
        rule_id=SECURITY_RULE_ID,
    )



"""
Get a list of events returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.events_api import EventsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = EventsApi(api_client)
    response = api_instance.list_events(
        start=9223372036854775807,
        end=9223372036854775807,
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    none_type,
    unset,
    UnsetType,
)


class HourlyUsageAttributionPagination(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "next_record_id": (str, none_type),
        }

    attribute_map = {
        "next_record_id": "next_record_id",
    }

    def __init__(self_, next_record_id: Union[str, none_type, UnsetType] = unset, **kwargs):
        """
        The metadata for the current pagination.

        :param next_record_id: The cursor to get the next results (if any). To make the next request, use the same parameters and add ``next_record_id``.
        :type next_record_id: str, none_type, optional
        """
        if next_record_id is not unset:
            kwargs["next_record_id"] = next_record_id
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.usage_top_avg_metrics_metadata import UsageTopAvgMetricsMetadata
    from datadog_api_client.v1.model.usage_top_avg_metrics_hour import UsageTopAvgMetricsHour


class UsageTopAvgMetricsResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.usage_top_avg_metrics_metadata import UsageTopAvgMetricsMetadata
        from datadog_api_client.v1.model.usage_top_avg_metrics_hour import UsageTopAvgMetricsHour

        return {
            "metadata": (UsageTopAvgMetricsMetadata,),
            "usage": ([UsageTopAvgMetricsHour],),
        }

    attribute_map = {
        "metadata": "metadata",
        "usage": "usage",
    }

    def __init__(
        self_,
        metadata: Union[UsageTopAvgMetricsMetadata, UnsetType] = unset,
        usage: Union[List[UsageTopAvgMetricsHour], UnsetType] = unset,
        **kwargs,
    ):
        """
        Response containing the number of hourly recorded custom metrics for a given organization.

        :param metadata: The object containing document metadata.
        :type metadata: UsageTopAvgMetricsMetadata, optional

        :param usage: Number of hourly recorded custom metrics for a given organization.
        :type usage: [UsageTopAvgMetricsHour], optional
        """
        if metadata is not unset:
            kwargs["metadata"] = metadata
        if usage is not unset:
            kwargs["usage"] = usage
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.audit_logs_query_filter import AuditLogsQueryFilter
    from datadog_api_client.v2.model.audit_logs_query_options import AuditLogsQueryOptions
    from datadog_api_client.v2.model.audit_logs_query_page_options import AuditLogsQueryPageOptions
    from datadog_api_client.v2.model.audit_logs_sort import AuditLogsSort


class AuditLogsSearchEventsRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.audit_logs_query_filter import AuditLogsQueryFilter
        from datadog_api_client.v2.model.audit_logs_query_options import AuditLogsQueryOptions
        from datadog_api_client.v2.model.audit_logs_query_page_options import AuditLogsQueryPageOptions
        from datadog_api_client.v2.model.audit_logs_sort import AuditLogsSort

        return {
            "filter": (AuditLogsQueryFilter,),
            "options": (AuditLogsQueryOptions,),
            "page": (AuditLogsQueryPageOptions,),
            "sort": (AuditLogsSort,),
        }

    attribute_map = {
        "filter": "filter",
        "options": "options",
        "page": "page",
        "sort": "sort",
    }

    def __init__(
        self_,
        filter: Union[AuditLogsQueryFilter, UnsetType] = unset,
        options: Union[AuditLogsQueryOptions, UnsetType] = unset,
        page: Union[AuditLogsQueryPageOptions, UnsetType] = unset,
        sort: Union[AuditLogsSort, UnsetType] = unset,
        **kwargs,
    ):
        """
        The request for a Audit Logs events list.

        :param filter: Search and filter query settings.
        :type filter: AuditLogsQueryFilter, optional

        :param options: Global query options that are used during the query.
            Note: Specify either timezone or time offset, not both. Otherwise, the query fails.
        :type options: AuditLogsQueryOptions, optional

        :param page: Paging attributes for listing events.
        :type page: AuditLogsQueryPageOptions, optional

        :param sort: Sort parameters when querying events.
        :type sort: AuditLogsSort, optional
        """
        if filter is not unset:
            kwargs["filter"] = filter
        if options is not unset:
            kwargs["options"] = options
        if page is not unset:
            kwargs["page"] = page
        if sort is not unset:
            kwargs["sort"] = sort
        super().__init__(kwargs)



"""
Update a log-based metric with include_percentiles field returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.logs_metrics_api import LogsMetricsApi
from datadog_api_client.v2.model.logs_metric_type import LogsMetricType
from datadog_api_client.v2.model.logs_metric_update_attributes import LogsMetricUpdateAttributes
from datadog_api_client.v2.model.logs_metric_update_compute import LogsMetricUpdateCompute
from datadog_api_client.v2.model.logs_metric_update_data import LogsMetricUpdateData
from datadog_api_client.v2.model.logs_metric_update_request import LogsMetricUpdateRequest

# there is a valid "logs_metric_percentile" in the system
LOGS_METRIC_PERCENTILE_DATA_ID = environ["LOGS_METRIC_PERCENTILE_DATA_ID"]

body = LogsMetricUpdateRequest(
    data=LogsMetricUpdateData(
        type=LogsMetricType.LOGS_METRICS,
        attributes=LogsMetricUpdateAttributes(
            compute=LogsMetricUpdateCompute(
                include_percentiles=False,
            ),
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = LogsMetricsApi(api_client)
    response = api_instance.update_logs_metric(metric_id=LOGS_METRIC_PERCENTILE_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.metrics_aggregator import MetricsAggregator
    from datadog_api_client.v2.model.metrics_data_source import MetricsDataSource


class MetricsScalarQuery(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.metrics_aggregator import MetricsAggregator
        from datadog_api_client.v2.model.metrics_data_source import MetricsDataSource

        return {
            "aggregator": (MetricsAggregator,),
            "data_source": (MetricsDataSource,),
            "name": (str,),
            "query": (str,),
        }

    attribute_map = {
        "aggregator": "aggregator",
        "data_source": "data_source",
        "name": "name",
        "query": "query",
    }

    def __init__(
        self_,
        aggregator: MetricsAggregator,
        data_source: MetricsDataSource,
        query: str,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        An individual scalar metrics query.

        :param aggregator: The type of aggregation that can be performed on metrics queries.
        :type aggregator: MetricsAggregator

        :param data_source: A data source that is powered by the Metrics backend.
        :type data_source: MetricsDataSource

        :param name: The variable name for use in formulas.
        :type name: str, optional

        :param query: A classic metrics query string.
        :type query: str
        """
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)

        self_.aggregator = aggregator
        self_.data_source = data_source
        self_.query = query



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.logs_compute import LogsCompute
    from datadog_api_client.v2.model.logs_query_filter import LogsQueryFilter
    from datadog_api_client.v2.model.logs_group_by import LogsGroupBy
    from datadog_api_client.v2.model.logs_query_options import LogsQueryOptions
    from datadog_api_client.v2.model.logs_aggregate_request_page import LogsAggregateRequestPage


class LogsAggregateRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.logs_compute import LogsCompute
        from datadog_api_client.v2.model.logs_query_filter import LogsQueryFilter
        from datadog_api_client.v2.model.logs_group_by import LogsGroupBy
        from datadog_api_client.v2.model.logs_query_options import LogsQueryOptions
        from datadog_api_client.v2.model.logs_aggregate_request_page import LogsAggregateRequestPage

        return {
            "compute": ([LogsCompute],),
            "filter": (LogsQueryFilter,),
            "group_by": ([LogsGroupBy],),
            "options": (LogsQueryOptions,),
            "page": (LogsAggregateRequestPage,),
        }

    attribute_map = {
        "compute": "compute",
        "filter": "filter",
        "group_by": "group_by",
        "options": "options",
        "page": "page",
    }

    def __init__(
        self_,
        compute: Union[List[LogsCompute], UnsetType] = unset,
        filter: Union[LogsQueryFilter, UnsetType] = unset,
        group_by: Union[List[LogsGroupBy], UnsetType] = unset,
        options: Union[LogsQueryOptions, UnsetType] = unset,
        page: Union[LogsAggregateRequestPage, UnsetType] = unset,
        **kwargs,
    ):
        """
        The object sent with the request to retrieve a list of logs from your organization.

        :param compute: The list of metrics or timeseries to compute for the retrieved buckets.
        :type compute: [LogsCompute], optional

        :param filter: The search and filter query settings
        :type filter: LogsQueryFilter, optional

        :param group_by: The rules for the group by
        :type group_by: [LogsGroupBy], optional

        :param options: Global query options that are used during the query.
            Note: You should only supply timezone or time offset but not both otherwise the query will fail.
        :type options: LogsQueryOptions, optional

        :param page: Paging settings
        :type page: LogsAggregateRequestPage, optional
        """
        if compute is not unset:
            kwargs["compute"] = compute
        if filter is not unset:
            kwargs["filter"] = filter
        if group_by is not unset:
            kwargs["group_by"] = group_by
        if options is not unset:
            kwargs["options"] = options
        if page is not unset:
            kwargs["page"] = page
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.nullable_relationship_to_user import NullableRelationshipToUser


class IncidentCreateRelationships(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.nullable_relationship_to_user import NullableRelationshipToUser

        return {
            "commander_user": (NullableRelationshipToUser,),
        }

    attribute_map = {
        "commander_user": "commander_user",
    }

    def __init__(self_, commander_user: NullableRelationshipToUser, **kwargs):
        """
        The relationships the incident will have with other resources once created.

        :param commander_user: Relationship to user.
        :type commander_user: NullableRelationshipToUser
        """
        super().__init__(kwargs)

        self_.commander_user = commander_user



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class UsageSort(ModelSimple):
    """
    The field to sort by.

    :param value: If omitted defaults to "start_date". Must be one of ["computed_on", "size", "start_date", "end_date"].
    :type value: str
    """

    allowed_values = {
        "computed_on",
        "size",
        "start_date",
        "end_date",
    }
    COMPUTED_ON: ClassVar["UsageSort"]
    SIZE: ClassVar["UsageSort"]
    START_DATE: ClassVar["UsageSort"]
    END_DATE: ClassVar["UsageSort"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


UsageSort.COMPUTED_ON = UsageSort("computed_on")
UsageSort.SIZE = UsageSort("size")
UsageSort.START_DATE = UsageSort("start_date")
UsageSort.END_DATE = UsageSort("end_date")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class WidgetSizeFormat(ModelSimple):
    """
    Size of the widget.

    :param value: Must be one of ["small", "medium", "large"].
    :type value: str
    """

    allowed_values = {
        "small",
        "medium",
        "large",
    }
    SMALL: ClassVar["WidgetSizeFormat"]
    MEDIUM: ClassVar["WidgetSizeFormat"]
    LARGE: ClassVar["WidgetSizeFormat"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


WidgetSizeFormat.SMALL = WidgetSizeFormat("small")
WidgetSizeFormat.MEDIUM = WidgetSizeFormat("medium")
WidgetSizeFormat.LARGE = WidgetSizeFormat("large")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class ContentEncoding(ModelSimple):
    """
    HTTP header used to compress the media-type.

    :param value: Must be one of ["gzip", "deflate"].
    :type value: str
    """

    allowed_values = {
        "gzip",
        "deflate",
    }
    GZIP: ClassVar["ContentEncoding"]
    DEFLATE: ClassVar["ContentEncoding"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


ContentEncoding.GZIP = ContentEncoding("gzip")
ContentEncoding.DEFLATE = ContentEncoding("deflate")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, List, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v1.model.downtime import Downtime
from datadog_api_client.v1.model.canceled_downtimes_ids import CanceledDowntimesIds
from datadog_api_client.v1.model.cancel_downtimes_by_scope_request import CancelDowntimesByScopeRequest


class DowntimesApi:
    """
    `Downtiming <https://docs.datadoghq.com/monitors/notify/downtimes>`_ gives
    you greater control over monitor notifications by allowing you to globally exclude
    scopes from alerting. Downtime settings, which can be scheduled with start and
    end times, prevent all alerting related to specified Datadog tags.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._cancel_downtime_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/downtime/{downtime_id}",
                "operation_id": "cancel_downtime",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "downtime_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "downtime_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._cancel_downtimes_by_scope_endpoint = _Endpoint(
            settings={
                "response_type": (CanceledDowntimesIds,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/downtime/cancel/by_scope",
                "operation_id": "cancel_downtimes_by_scope",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (CancelDowntimesByScopeRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._create_downtime_endpoint = _Endpoint(
            settings={
                "response_type": (Downtime,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/downtime",
                "operation_id": "create_downtime",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (Downtime,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._get_downtime_endpoint = _Endpoint(
            settings={
                "response_type": (Downtime,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/downtime/{downtime_id}",
                "operation_id": "get_downtime",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "downtime_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "downtime_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_downtimes_endpoint = _Endpoint(
            settings={
                "response_type": ([Downtime],),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/downtime",
                "operation_id": "list_downtimes",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "current_only": {
                    "openapi_types": (bool,),
                    "attribute": "current_only",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_monitor_downtimes_endpoint = _Endpoint(
            settings={
                "response_type": ([Downtime],),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/monitor/{monitor_id}/downtimes",
                "operation_id": "list_monitor_downtimes",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "monitor_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "monitor_id",
                    "location": "path",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_downtime_endpoint = _Endpoint(
            settings={
                "response_type": (Downtime,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/downtime/{downtime_id}",
                "operation_id": "update_downtime",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "downtime_id": {
                    "required": True,
                    "openapi_types": (int,),
                    "attribute": "downtime_id",
                    "location": "path",
                },
                "body": {
                    "required": True,
                    "openapi_types": (Downtime,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def cancel_downtime(
        self,
        downtime_id: int,
    ) -> None:
        """Cancel a downtime.

        Cancel a downtime.

        :param downtime_id: ID of the downtime to cancel.
        :type downtime_id: int
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["downtime_id"] = downtime_id

        return self._cancel_downtime_endpoint.call_with_http_info(**kwargs)

    def cancel_downtimes_by_scope(
        self,
        body: CancelDowntimesByScopeRequest,
    ) -> CanceledDowntimesIds:
        """Cancel downtimes by scope.

        Delete all downtimes that match the scope of ``X``.

        :param body: Scope to cancel downtimes for.
        :type body: CancelDowntimesByScopeRequest
        :rtype: CanceledDowntimesIds
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._cancel_downtimes_by_scope_endpoint.call_with_http_info(**kwargs)

    def create_downtime(
        self,
        body: Downtime,
    ) -> Downtime:
        """Schedule a downtime.

        Schedule a downtime.

        :param body: Schedule a downtime request body.
        :type body: Downtime
        :rtype: Downtime
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._create_downtime_endpoint.call_with_http_info(**kwargs)

    def get_downtime(
        self,
        downtime_id: int,
    ) -> Downtime:
        """Get a downtime.

        Get downtime detail by ``downtime_id``.

        :param downtime_id: ID of the downtime to fetch.
        :type downtime_id: int
        :rtype: Downtime
        """
        kwargs: Dict[str, Any] = {}
        kwargs["downtime_id"] = downtime_id

        return self._get_downtime_endpoint.call_with_http_info(**kwargs)

    def list_downtimes(
        self,
        *,
        current_only: Union[bool, UnsetType] = unset,
    ) -> List[Downtime]:
        """Get all downtimes.

        Get all scheduled downtimes.

        :param current_only: Only return downtimes that are active when the request is made.
        :type current_only: bool, optional
        :rtype: [Downtime]
        """
        kwargs: Dict[str, Any] = {}
        if current_only is not unset:
            kwargs["current_only"] = current_only

        return self._list_downtimes_endpoint.call_with_http_info(**kwargs)

    def list_monitor_downtimes(
        self,
        monitor_id: int,
    ) -> List[Downtime]:
        """Get all downtimes for a monitor.

        Get all active downtimes for the specified monitor.

        :param monitor_id: The id of the monitor
        :type monitor_id: int
        :rtype: [Downtime]
        """
        kwargs: Dict[str, Any] = {}
        kwargs["monitor_id"] = monitor_id

        return self._list_monitor_downtimes_endpoint.call_with_http_info(**kwargs)

    def update_downtime(
        self,
        downtime_id: int,
        body: Downtime,
    ) -> Downtime:
        """Update a downtime.

        Update a single downtime by ``downtime_id``.

        :param downtime_id: ID of the downtime to update.
        :type downtime_id: int
        :param body: Update a downtime request body.
        :type body: Downtime
        :rtype: Downtime
        """
        kwargs: Dict[str, Any] = {}
        kwargs["downtime_id"] = downtime_id

        kwargs["body"] = body

        return self._update_downtime_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.logs_archive_create_request_attributes import LogsArchiveCreateRequestAttributes


class LogsArchiveCreateRequestDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.logs_archive_create_request_attributes import (
            LogsArchiveCreateRequestAttributes,
        )

        return {
            "attributes": (LogsArchiveCreateRequestAttributes,),
            "type": (str,),
        }

    attribute_map = {
        "attributes": "attributes",
        "type": "type",
    }

    def __init__(self_, attributes: Union[LogsArchiveCreateRequestAttributes, UnsetType] = unset, **kwargs):
        """
        The definition of an archive.

        :param attributes: The attributes associated with the archive.
        :type attributes: LogsArchiveCreateRequestAttributes, optional

        :param type: The type of the resource. The value should always be archives.
        :type type: str
        """
        if attributes is not unset:
            kwargs["attributes"] = attributes
        super().__init__(kwargs)
        type = kwargs.get("type", "archives")

        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.security_filter_exclusion_filter import SecurityFilterExclusionFilter
    from datadog_api_client.v2.model.security_filter_filtered_data_type import SecurityFilterFilteredDataType


class SecurityFilterCreateAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.security_filter_exclusion_filter import SecurityFilterExclusionFilter
        from datadog_api_client.v2.model.security_filter_filtered_data_type import SecurityFilterFilteredDataType

        return {
            "exclusion_filters": ([SecurityFilterExclusionFilter],),
            "filtered_data_type": (SecurityFilterFilteredDataType,),
            "is_enabled": (bool,),
            "name": (str,),
            "query": (str,),
        }

    attribute_map = {
        "exclusion_filters": "exclusion_filters",
        "filtered_data_type": "filtered_data_type",
        "is_enabled": "is_enabled",
        "name": "name",
        "query": "query",
    }

    def __init__(
        self_,
        exclusion_filters: List[SecurityFilterExclusionFilter],
        filtered_data_type: SecurityFilterFilteredDataType,
        is_enabled: bool,
        name: str,
        query: str,
        **kwargs,
    ):
        """
        Object containing the attributes of the security filter to be created.

        :param exclusion_filters: Exclusion filters to exclude some logs from the security filter.
        :type exclusion_filters: [SecurityFilterExclusionFilter]

        :param filtered_data_type: The filtered data type.
        :type filtered_data_type: SecurityFilterFilteredDataType

        :param is_enabled: Whether the security filter is enabled.
        :type is_enabled: bool

        :param name: The name of the security filter.
        :type name: str

        :param query: The query of the security filter.
        :type query: str
        """
        super().__init__(kwargs)

        self_.exclusion_filters = exclusion_filters
        self_.filtered_data_type = filtered_data_type
        self_.is_enabled = is_enabled
        self_.name = name
        self_.query = query



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class UsageSNMPHour(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "hour": (datetime,),
            "org_name": (str,),
            "public_id": (str,),
            "snmp_devices": (int,),
        }

    attribute_map = {
        "hour": "hour",
        "org_name": "org_name",
        "public_id": "public_id",
        "snmp_devices": "snmp_devices",
    }

    def __init__(
        self_,
        hour: Union[datetime, UnsetType] = unset,
        org_name: Union[str, UnsetType] = unset,
        public_id: Union[str, UnsetType] = unset,
        snmp_devices: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        The number of SNMP devices for each hour for a given organization.

        :param hour: The hour for the usage.
        :type hour: datetime, optional

        :param org_name: The organization name.
        :type org_name: str, optional

        :param public_id: The organization public ID.
        :type public_id: str, optional

        :param snmp_devices: Contains the number of SNMP devices.
        :type snmp_devices: int, optional
        """
        if hour is not unset:
            kwargs["hour"] = hour
        if org_name is not unset:
            kwargs["org_name"] = org_name
        if public_id is not unset:
            kwargs["public_id"] = public_id
        if snmp_devices is not unset:
            kwargs["snmp_devices"] = snmp_devices
        super().__init__(kwargs)



"""
Create an application key returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.key_management_api import KeyManagementApi
from datadog_api_client.v1.model.application_key import ApplicationKey

body = ApplicationKey(
    name="example user",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = KeyManagementApi(api_client)
    response = api_instance.create_application_key(body=body)

    print(response)
